/*
   PoV 1.0 input file
   The Neat New Toy (tm)
   This is a toy made by Kinderworks.
   I didn't design the toy, and don't claim to have.
   I did define it for PoVRay.  Let me know if you like it.
   Bruce A. Bacher
*/

#include "colors.inc"
#include "textures.inc"
#include "shapes.inc"
#include "toyanim.inc"

/****************************** BITS *****************************************/
#declare HRod =
  object {
    intersection {
      Disk_X
      scale <3.09375 .1875 .1875>
      translate <3.09375 0 0>
    }
    texture {
      DMFWood4 //Yellow_Pine
      rotate <0 88 0>
      scale <1 1 1>
      ambient .2
      diffuse .8
    }
    bounded_by { box {<-.01 -.19 -.19><6.2 .19 .19>}}
  }

#declare HBrassRod =
  object {
    intersection {
      Disk_X
      scale <2.0625 .1875 .1875>
      translate <2.0625 0 0>
    }
    texture { Brass_Metal  ambient .2 diffuse .8 }
    bounded_by { box {<-.01 -.19 -.19><4.15 .19 .19>}}
  }

#declare VRod =
  object {
    intersection {
      Disk_Y
      scale <.1875 3.09375 .1875>
      translate <0 -3.09375 0>
    }
    texture {
      DMFWood4 //Yellow_Pine
      rotate <88 0 0>
      scale <1 1 1>
      ambient .2
      diffuse .8
    }
    bounded_by { box {<-.19 -6.2 -.19><.19 .01 .19>}}
  }

#declare VBrassRod=
  object {
    intersection {
      Disk_Y
      scale <.1875 2.0625 .1875>
      translate <0 -2.0625 0>
    }
    texture { Brass_Metal  ambient .2 diffuse .8 }
    bounded_by { box {<-.19 -4.15 -.19><.19 .01 .19>}}
  }

#declare HDisk =
  object {
    difference {
      intersection { Disk_Y  scale <1.75 .25 1.75>}
      intersection {
        Disk_Y
        scale <.23 .26 .23>
        translate <-1.25 0 0>
        rotate <0 0 0>
      }
      intersection {
        Disk_Y
        scale <.23 .26 .23>
        translate <-1.25 0 0>
        rotate <0 72 0>
      }
      intersection {
        Disk_Y
        scale <.23 .26 .23>
        translate <-1.25 0 0>
        rotate <0 144 0>
      }
      intersection {
        Disk_Y
        scale <.23 .26 .23>
        translate <-1.25 0 0>
        rotate <0 216 0>
      }
      intersection {
        Disk_Y
        scale <.23 .26 .23>
        translate <-1.25 0 0>
        rotate <0 288 0>
      }
      intersection {
        Disk_Y
        scale <.21875 .26 .21875>
      }
    }
    texture {
      DMFWood4
      rotate <80 0 0>
      scale <8 8 8>
      translate <20 0 20>
      ambient .2
      diffuse .8
    }
    bounded_by { box {<-1.76 -.26 -1.76><1.76 .26 1.76>}}
  }

#declare HDiskAssemblyPost =
  object {
    intersection { Disk_Y  scale <.1875 .5625 .1875>}
    texture {
      DMFWood4
      rotate <88 0 0>
      scale <1 1 1>
      ambient .2
      diffuse .8
    }
    bounded_by { box {<-.19 -.57 -.19><.19 .57 .19>}}
  }

#declare RubberRing =
  object {
    quartic {
    <   1.000000 0.000000 0.000000 0.000000 2.000000
        0.000000 0.000000 2.000000 0.000000 -10.712891
        0.000000 0.000000 0.000000 0.000000 0.000000
        0.000000 0.000000 0.000000 0.000000 0.000000
        1.000000 0.000000 0.000000 2.000000 0.000000
        10.677734 0.000000 0.000000 0.000000 0.000000
        1.000000 0.000000 -10.712891 0.000000 28.503503 >
    }
  texture { Dull color Black }
  bounded_by { box {<-2.5 -.1 -2.5><2.5 .1 2.5>}}
  }

#declare VDisk =
  composite {
    object {
      difference {
        intersection { Disk_X  scale <.25 2.3125 2.3125>}
        intersection {
          Disk_X
          scale <.26 .23 .23>
          translate <0 1.3125 0>
          rotate <0 0 0>
        }
        intersection {
          Disk_X
          scale <.26 .23 .23>
          translate <0 1.3125 0>
          rotate <72 0 0>
        }
        intersection {
          Disk_X
          scale <.26 .23 .23>
          translate <0 1.3125 0>
          rotate <144 0 0>
        }
        intersection {
          Disk_X
          scale <.26 .23 .23>
          translate <0 1.3125 0>
          rotate <216 0 0>
        }
        intersection {
          Disk_X
          scale <.26 .23 .23>
          translate <0 1.3125 0>
          rotate <288 0 0>
        }
        intersection {
          Disk_X
          scale <.26 .21875 .21875>
        }
      }
      texture {
        DMFWood4
        rotate <0 80 0>
        scale <8 8 8>
        translate <0 20 20>
        ambient .2
        diffuse .8
      }
    }
    object { RubberRing  rotate <0 0 90>}
    bounded_by { box {<-.26 -2.41 -2.41><.26 2.41 2.41>}}
  }

#declare VDiskAssemblyPost =
  object {
    intersection { Disk_X  scale <.5625 .1875 .1875>}
    texture {
      DMFWood4
      rotate <0 88 0>
      scale <1 1 1>
      ambient .2
      diffuse .8
    }
    bounded_by { box {<-.57 -.19 -.19><.57 .19 .19>}}
  }

// Before translation, the _bottom center_ of EndNut lies at the origin.
#declare EndNut =
  object {
    union {
      intersection {
        plane {<0 -1 0> 0}
        plane {<1 0 0> .3125 rotate <0 0 0>}
        plane {<1 0 0> .3125 rotate <0 60 0>}
        plane {<1 0 0> .3125 rotate <0 120 0>}
        plane {<1 0 0> .3125 rotate <0 180 0>}
        plane {<1 0 0> .3125 rotate <0 240 0>}
        plane {<1 0 0> .3125 rotate <0 300 0>}
        plane {<0 1 0> .1875}
      }
      sphere {<0 .1875 0> .3125 }
    }
    texture { Brass_Metal  ambient .2 diffuse .8 }
    bounded_by { box {<-.315 -.01 -.315><.315 .51 .315>}}
  }

// Before translation, _center_ of HWasher is at the origin.
#declare HWasher =
  object {
    intersection { Disk_Y  scale <.40625 .04688 .40625> }
    texture { Brass_Metal  ambient .2 diffuse .8 }
    bounded_by { box {<-.41 -.047 -.41><.41 .047 .41>}}
  }

// Before translation, _center_ of VWasher is at the origin.
#declare VWasher =
  object {
    intersection { Disk_X  scale <.04688 .40625 .40625> }
    texture { Brass_Metal  ambient .2 diffuse .8 }
    bounded_by { box {<-.047 -.41 -.41><.047 .41 .41>}}
  }

#declare Shaft =
  object {
    intersection { Disk_Y  scale <.34375 1 .34375>}
    texture {
      DMFWood4
      rotate <88 0 0>
      scale <1 1 1>
      ambient .2
      diffuse .8
    }
    bounded_by { box {<-.345 -1.01 -.345><.345 1.01 .345>}}
  }

/* The bits of the Handle are positioned based upon the final coordinates
    of the system.  The top of HandleBlock is at y=0, the center of
    HandleRod is on the Y-axis. */
#declare HandleBlock =
  object {
    union {
      box {<-2.1875 -2 -.53125><2.1875 0 .53125>}
      intersection { Disk_Y  scale <.53125 1 .53125> translate <-1.96875 -1 0>}
      intersection { Disk_Y  scale <.53125 1 .53125> translate <1.96875 -1 0>}
    }
      texture {
      DMFWood4
      rotate <0 88 0>
      scale <2 2 2>
      ambient .2
      diffuse .8
    }
    bounded_by { box {<-2.51 -2.01 -.54><2.51 0.01 .54>}}
  }

#declare HandleRod =
  object {
    intersection { Disk_Y  scale <.28125 7.75 .28125> translate <0 7.75 0>}
    texture {
      DMFWood4
      rotate <88 0 0>
      scale <2 2 2>
      ambient .2
      diffuse .8
    }
    bounded_by { box {<-.282 -.01 -.282><.282 15.51 .282>}}
  }

#declare HandleGrip =
  object {
    union {
      sphere {<-2.25 15.5 0> .5 }
      intersection {
          Disk_X
          scale <2.25 .5 .5>
          translate <0 15.5 0>
      }
      sphere {<2.25 15.5 0> .5 }
    }
    texture {
      DMFWood4
      rotate <0 88 0>
      scale <1 1 1>
      translate <0 0 5>
      ambient .2
      diffuse .8
    }
    bounded_by { box {<-2.26 14.9 -.51><2.26 16.1 .51>}}
  }

/****************************** PIECES ***************************************/
// An LPiece #declare is needed for each, since the color of spheres changes.
// The LPieces are defined so that the center sphere is at the origin.
#declare RedLPiece =
  composite {
    object {
      sphere {<0 -6.1875 0> .53125}
      texture { color Red ambient .2 diffuse .8 }
    }
    object { VRod rotate <0 0 0>}
    object {
      sphere {<0 0 0> .53125}
      texture { color Red ambient .2 diffuse .8 }
    }
    object { HRod rotate <0 0 0>}
    object {
      sphere {<6.1875 0 0> .53125}
      texture { color Red ambient .2 diffuse .8 }
    }
    bounded_by { box {<-.55 -6.75 -.55><6.75 .55 .55>}}
  }

#declare GreenLPiece =
  composite {
    object {
      sphere {<0 -6.1875 0> .53125}
      texture { color PineGreen ambient .2 diffuse .8 }
    }
    object { VRod rotate <0 72 0>}
    object {
      sphere {<0 0 0> .53125}
      texture { color PineGreen ambient .2 diffuse .8 }
    }
    object { HRod  rotate <72 0 0>}
    object {
      sphere {<6.1875 0 0> .53125}
      texture { color PineGreen ambient .2 diffuse .8 }
    }
    bounded_by { box {<-.55 -6.75 -.55><6.75 .55 .55>}}
  }

#declare YellowLPiece =
  composite {
    object {
      sphere {<0 -6.1875 0> .53125}
      texture { color Gold ambient .2 diffuse .8 }
    }
    object { VRod rotate <0 144 0>}
    object {
      sphere {<0 0 0> .53125}
      texture { color Gold ambient .2 diffuse .8 }
    }
    object { HRod  rotate <144 0 0>}
    object {
      sphere {<6.1875 0 0> .53125}
      texture { color Gold ambient .2 diffuse .8 }
    }
    bounded_by { box {<-.55 -6.75 -.55><6.75 .55 .55>}}
  }

#declare OrangeLPiece =
  composite {
    object {
      sphere {<0 -6.1875 0> .53125}
      texture { color Orange ambient .2 diffuse .8 }
    }
    object { VRod rotate <0 216 0>}
    object {
      sphere {<0 0 0> .53125}
      texture { color Orange ambient .2 diffuse .8 }
    }
    object { HRod  rotate <216 0 0>}
    object {
      sphere {<6.1875 0 0> .53125}
      texture { color Orange ambient .2 diffuse .8 }
    }
  }

#declare BlueLPiece =
  composite {
    object {
      sphere {<0 -6.1875 0> .53125}
      texture { color Aquamarine ambient .2 diffuse .8 }
    }
    object { VRod rotate <0 288 0>}
    object {
      sphere {<0 0 0> .53125}
      texture { color Aquamarine ambient .2 diffuse .8 }
    }
    object { HRod  rotate <288 0 0>}
    object {
      sphere {<6.1875 0 0> .53125}
      texture { color Aquamarine ambient .2 diffuse .8 }
    }
    bounded_by { box {<-.55 -6.75 -.55><6.75 .55 .55>}}
  }

#declare BrassLPiece =
  composite {
    object { VBrassRod }
    object {
      sphere {<0 0 0> .1875}
      texture { Brass_Metal  ambient .2 diffuse .8 }
    }
    object { HBrassRod }
    bounded_by { box {<-.19 -4.15 -.19><4.15 .19 .19>}}
  }

// The center of the top of the top disk of HDiskAssembly (the disk nearest
// the bend) is at the Origin.
declare HDiskAssembly =
  composite {
    object { HDisk  translate <0 -.25 0>}
    object { HDiskAssemblyPost  translate <-1.25 -1.0625 0> rotate <0 36 0>}
    object { HDiskAssemblyPost  translate <-1.25 -1.0625 0> rotate <0 108 0>}
    object { HDiskAssemblyPost  translate <-1.25 -1.0625 0> rotate <0 180 0>}
    object { HDiskAssemblyPost  translate <-1.25 -1.0625 0> rotate <0 252 0>}
    object { HDiskAssemblyPost  translate <-1.25 -1.0625 0> rotate <0 324 0>}
    object { HDisk  rotate <0 144 0> translate <0 -1.875 0>}
    object { HWasher  translate <0 .04688 0>}
    object { HWasher  translate <0 -2.179 0>}
    bounded_by { box {<-1.8 -2.23 -1.8><1.8 .01 1.8>}}
  }

// The center of the left side of the left disk of VDiskAssembly (the disk
// nearest the bend) is at the Origin prior to translation, for easy rotation.
declare VDiskAssembly =
  composite {
    composite { VDisk  translate <.25 0 0>}
    object { VDiskAssemblyPost  translate <1.0625 1.3125 0> rotate <36 0 0>}
    object { VDiskAssemblyPost  translate <1.0625 1.3125 0> rotate <108 0 0>}
    object { VDiskAssemblyPost  translate <1.0625 1.3125 0> rotate <180 0 0>}
    object { VDiskAssemblyPost  translate <1.0625 1.3125 0> rotate <252 0 0>}
    object { VDiskAssemblyPost  translate <1.0625 1.3125 0> rotate <324 0 0>}
    composite { VDisk  rotate <144 0 0> translate <1.875 0 0>}
    object { VWasher  translate <-.04688 0 0>}
    object { VWasher  translate <2.179 0 0>}
    object { EndNut  rotate <0 0 90> translate <2.22588 0 0>}
    bounded_by { box {<-.01 -2.35 -2.35><2.75 2.35 2.35>}}
  }

/*The following discussion applies to the right side of the whole.  Reversal
    of some things is necessary for the left side.
  Let  be the rotation angle with respect to the disks.   = 0 on -x axis
    for the HDisks, or +y axis for the VDisks.
  Then the coordinates of each of the center spheres of the LPieces (at the
    bend in the L) depend upon the angles Red, Yellow, etc. which define
    the starting positions of the spheres.  The angle of rotation used to
    define the positions of the spheres is Color = Red + , Yellow + , etc.
  At the beginning:  Red = 0
                     Yellow = 72
                     Blue = 144
                     Orange = 216
                     Green = 288
  To get the coordinates for the sphere colored Color, find Color for a
    given , then <x,y,z> = <-1.25(cos) [1.3125(cos) + 2]  1.25(sin)>
    for the right side.  For the left side, reverse the signs of x and z.
*/

#declare RightSide =
  composite {
    composite { HDiskAssembly  rotate <0 RHDA 0>}
    composite { RedLPiece  translate <RRLPX RRLPY RRLPZ>}
    composite { YellowLPiece  translate <RYLPX RYLPY RYLPZ>}
    composite { BlueLPiece  translate <RBLPX RBLPY RBLPZ>}
    composite { OrangeLPiece  translate <ROLPX ROLPY ROLPZ>}
    composite { GreenLPiece  translate <RGLPX RGLPY RGLPZ>}
    composite { VDiskAssembly  rotate <RVDA 0 0> translate <2 2 0>}
    composite { BrassLPiece  translate <0 2 0>}
    object { Shaft translate <0 -3.2259 0>}
    bounded_by { box {<-2.5 -6.5 -3><9 5 3>}}
  }

#declare LeftSide =
  composite {
    composite { HDiskAssembly  rotate <0 LHDA 0>}
    composite { RedLPiece  rotate <0 180 0> translate <LRLPX LRLPY LRLPZ>}
    composite { YellowLPiece  rotate <0 180 0> translate <LYLPX LYLPY LYLPZ>}
    composite { BlueLPiece  rotate <0 180 0> translate <LBLPX LBLPY LBLPZ>}
    composite { OrangeLPiece  rotate <0 180 0> translate <LOLPX LOLPY LOLPZ>}
    composite { GreenLPiece  rotate <0 180 0> translate <LGLPX LGLPY LGLPZ>}
    composite { VDiskAssembly  rotate <LVDA 180 0> translate <-2 2 0>}
    composite { BrassLPiece  rotate <0 180 0> translate <0 2 0>}
    object { Shaft translate <0 -3.126 0>}
    bounded_by { box {<-9 -6.5 -3><2.5 5 3>}}
  }

#declare TheWorks =
  composite {
    composite { RightSide  rotate <180 0 0> translate <2 -6.25 0>}
    composite { LeftSide  rotate <180 0 0> translate <-2 -6.25 0>}
    bounded_by { box {<-11.6 -12.8 -3><11.6 0 3>}}
  }

/* Top of HandleBlock is at y=0, top of HandleGrip is at y=16, center of
    HandleRod is along Y-axis. */
#declare Handle =
  composite {
    object { HandleBlock }
    object { HandleRod }
    object { HandleGrip }
    bounded_by { box {<-2.8 -2.1 -.54><2.8 16.1 .54>}}
  }

#declare NewToy =
  composite {
    composite { TheWorks }
    composite { Handle }
  }

/****************************** LIGHTS, CAMERA *******************************/
camera {
  translate <0 0 -23>
  up <0 1 0>
  right <1.33333 0 0>
  direction <0 0 1.5>
  look_at <0 -5.5 0>
}

object { light_source {<-500 500 -1000> color White }}
object { light_source {<1000 500 -500> color White }}
/****************************** ACTION!!! ************************************/

composite { NewToy }
